<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.linknacional.com.br/
 * @since             1.0.0
 * @package           conteudo-gratuito-para-blog
 *
 * @wordpress-plugin
 * Plugin Name:       Conteúdo gratuito para Blog
 * Plugin URI:        https://www.linknacional.com.br/wordpress/plugins/
 * Description:       Importa conteúdos via RSS para o blog.
 * Version:           1.4.1
 * Author:            Link Nacional
 * Author URI:        https://www.linknacional.com.br/
 * License:           GPL-3.0+
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain:       conteudo-gratuito-para-blog
 * Domain Path:       /languages
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Define constants
define( 'CPB_PLUGIN_VERSION', '1.4.1' );
define( 'CPB_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'CPB_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

// Include necessary files
require_once CPB_PLUGIN_PATH . 'includes/class-cpb-importer.php';
require_once CPB_PLUGIN_PATH . 'includes/class-cpb-admin.php';

// Initialize the plugin
register_activation_hook( __FILE__, array('CPB_Importer', 'activate') );
register_deactivation_hook( __FILE__, array('CPB_Importer', 'deactivate') );

// Hook into the admin menu
add_action( 'admin_menu', array('CPB_Admin', 'add_admin_menu') );

// Plugin logic - Schedule weekly event
if ( ! wp_next_scheduled( 'cpb_import_rss_event' ) ) {
    wp_schedule_event( time(), 'weekly', 'cpb_import_rss_event' );
}
add_action( 'cpb_import_rss_event', array('CPB_Importer', 'import_rss') );

/**
 * Instância do updateChecker, ela exige os seguintes parâmetros:.
 *
 * url do JSON
 * caminho completo do arquivo principal do plugin
 * nome do diretório para instalação
 *
 * @return object
 */
function cpb_updater_init() {
    require_once CPB_PLUGIN_PATH . 'includes/plugin-updater/plugin-update-checker.php';

    return new Lkn_Puc_Plugin_UpdateChecker(
        'https://api.linknacional.com/v2/u/?slug=conteudo-gratuito-para-blog',
        __FILE__,// (caso o plugin não precise de compatibilidade com ioncube utilize: __FILE__), //Full path to the main plugin file or functions.php.
        'conteudo-gratuito-para-blog'
    );
}

cpb_updater_init();