<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

final class CPB_Admin {
    public static function add_admin_menu(): void {
        add_options_page(
            'Conteúdo gratuito para Blog',
            'Conteúdo gratuito para Blog',
            'manage_options',
            'cpb-settings',
            array(__CLASS__, 'create_admin_page')
        );
    }

    public static function create_admin_page(): void {
        ?>

<div class="wrap">
    <h1>Conteúdo gratuito para Blog</h1>
    <form
        method="post"
        action="options.php"
    >
        <?php
                settings_fields( 'cpb_settings_group' );
        do_settings_sections( 'cpb-settings' );
        submit_button();
        ?>
    </form>
    <form method="post">
        <input
            type="hidden"
            name="cpb_manual_import"
            value="1"
        >
        <?php submit_button( 'Importar Posts Manualmente' ); ?>
    </form>

    <?php
            if ( isset( $_POST['cpb_manual_import'] ) ) {
                $imported_posts = CPB_Importer::import_rss();
                echo '<h2>Resultado da Importação Manual</h2>';
                echo '<ul>';
                foreach ( $imported_posts as $post ) {
                    if ( $post['error'] ) {
                        echo '<li>Falha ao importar: ' . esc_html( $post['title'] ) . '. Erro: ' . esc_html( $post['error'] ) . '</li>';
                    } else {
                        echo '<li>Importado com sucesso: ' . esc_html( $post['title'] ) . '</li>';
                    }
                }
                echo '</ul>';
            }
        ?>
</div>

<?php
    }

    public static function setup_settings(): void {
        register_setting( 'cpb_settings_group', 'cpb_rss_feed', array(
            'type' => 'string',
            'sanitize_callback' => 'esc_url_raw',
            'default' => 'https://paraquemdoar.org/feed/',
        ) );

        register_setting( 'cpb_settings_group', 'cpb_default_status', array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => 'draft',
        ) );

        register_setting( 'cpb_settings_group', 'cpb_auto_import', array(
            'type' => 'boolean',
            'sanitize_callback' => 'rest_sanitize_boolean',
            'default' => false,
        ) );

        register_setting( 'cpb_settings_group', 'cpb_import_from_date', array(
            'type' => 'string',
            'sanitize_callback' => array(__CLASS__, 'sanitize_date'),
            'default' => '',
        ) );

        register_setting( 'cpb_settings_group', 'cpb_import_categories', array(
            'type' => 'array',
            'sanitize_callback' => array(__CLASS__, 'sanitize_categories'),
            'default' => array(),
        ) );

        add_settings_section(
            'cpb_settings_section',
            'Configurações de Importação',
            '__return_null',
            'cpb-settings'
        );

        add_settings_field(
            'cpb_rss_feed',
            'URL do RSS',
            array(__CLASS__, 'rss_feed_field_render'),
            'cpb-settings',
            'cpb_settings_section'
        );

        add_settings_field(
            'cpb_default_status',
            'Status Padrão do Post',
            array(__CLASS__, 'default_status_field_render'),
            'cpb-settings',
            'cpb_settings_section'
        );

        add_settings_field(
            'cpb_auto_import',
            'Importação Automática Semanal',
            array(__CLASS__, 'auto_import_field_render'),
            'cpb-settings',
            'cpb_settings_section'
        );

        add_settings_field(
            'cpb_import_from_date',
            'Importar Posts a partir de:',
            array(__CLASS__, 'import_from_date_field_render'),
            'cpb-settings',
            'cpb_settings_section'
        );

        add_settings_field(
            'cpb_import_categories',
            'Categorias para Importação:',
            array(__CLASS__, 'import_categories_field_render'),
            'cpb-settings',
            'cpb_settings_section'
        );
    }

    public static function rss_feed_field_render(): void {
        $rss_feed = get_option( 'cpb_rss_feed', 'https://paraquemdoar.org/feed/' );
        ?>
<input
    type="text"
    name="cpb_rss_feed"
    value="<?php echo esc_attr( $rss_feed ); ?>"
    class="regular-text"
>
<?php
    }

    public static function default_status_field_render(): void {
        $default_status = get_option( 'cpb_default_status', 'draft' );
        $statuses = array('draft', 'pending', 'publish', 'private', 'trash');
        ?>
<select name="cpb_default_status">
    <?php foreach ( $statuses as $status ) : ?>
    <option
        value="<?php echo esc_attr( $status ); ?>"
        <?php selected( $default_status, $status ); ?>>
            <?php echo __(ucfirst( $status )); ?>
    </option>
    <?php endforeach; ?>
</select>
<?php
    }

    public static function auto_import_field_render(): void {
        $auto_import = get_option( 'cpb_auto_import', false );
        ?>
<input
    type="checkbox"
    name="cpb_auto_import"
    value="1"
    <?php checked( $auto_import, true ); ?>>
    Ativar Importação Automática Semanal
<?php
    }

    public static function import_from_date_field_render(): void {
        $import_from_date = get_option( 'cpb_import_from_date', '' );
        ?>
<input
    type="date"
    name="cpb_import_from_date"
    value="<?php echo esc_attr( $import_from_date ); ?>"
    class="regular-text"
>
<?php
    }

    public static function import_categories_field_render(): void {
        $selected_categories = get_option( 'cpb_import_categories', array() );
        $categories = get_categories( array('hide_empty' => 0) );

        foreach ( $categories as $category ) {
            ?>
<input
    type="checkbox"
    name="cpb_import_categories[]"
    value="<?php echo esc_attr( $category->term_id ); ?>"
    <?php checked( in_array( $category->term_id, $selected_categories, true ) ); ?>>
    <?php echo esc_html( $category->name ); ?><br>
<?php
        }
    }

    public static function sanitize_date( $date ) {
        $date = wp_unslash( $date );
        $date_format = 'Y-m-d';
        $d = DateTime::createFromFormat( $date_format, $date );
        return $d && $d->format( $date_format ) === $date ? $date : '';
    }

    public static function sanitize_categories( $categories ) {
        // Return an empty array if $categories is null or not an array
        if ( ! is_array( $categories ) ) {
            return array();
        }
        return array_map( 'intval', $categories );
    }
}

add_action( 'admin_init', array('CPB_Admin', 'setup_settings') );